@@ -1,6 +1,9 @@
 package Catalyst::Plugin::MemoryUsage;
 BEGIN {
-  $Catalyst::Plugin::MemoryUsage::VERSION = '0.1.1';
+  $Catalyst::Plugin::MemoryUsage::AUTHORITY = 'cpan:yanick';
+}
+BEGIN {
+  $Catalyst::Plugin::MemoryUsage::VERSION = '0.2.0';
 }
 #ABSTRACT: Profile memory usage of requests
 
@@ -14,6 +17,9 @@ use MRO::Compat;
 use Memory::Usage;
 
 use Devel::CheckOS;
+use Text::SimpleTable;
+use Number::Bytes::Human qw/ format_bytes /;
+use List::Util qw/ max /;
 
 our @SUPPORTED_OSES = qw/ Linux NetBSD /;
 
@@ -37,6 +43,42 @@ sub reset_memory_usage {
     $self->memory_usage( Memory::Usage->new );
 }
 
+sub memory_usage_report {
+    my $self = shift;
+
+    my $title_width = max 10,
+        map { length $_->[1] } @{ $self->memory_usage->state };
+
+    my $table = Text::SimpleTable->new( 
+        [$title_width, ''],
+        [4, 'vsz'],
+        [4, 'delta'],
+        [4, 'rss'],
+        [4, 'delta'],
+        [4, 'shared'],
+        [4, 'delta'],
+        [4, 'code'],
+        [4, 'delta'],
+        [4, 'data'],
+        [4, 'delta'],
+    );
+
+    my @previous;
+
+    for my $s ( @{ $self->memory_usage->state } ) {
+        my ( $time, $msg, @sizes ) = @$s;
+
+        my @data = map { $_ ? format_bytes( 1024 * $_) : '' } map { 
+            ( $sizes[$_], @previous ? $sizes[$_] - $previous[$_]  : 0 )
+        } 0..4;
+        @previous = @sizes;
+
+        $table->row( $msg, @data );
+    }
+
+    return $table->draw;
+}
+
 unless ( $os_not_supported ) {
 
 after execute => sub {
@@ -62,7 +104,7 @@ around prepare => sub {
 before finalize => sub {
     my $c = shift;
 
-    $c->log->debug( 'memory usage of request', $c->memory_usage->report );
+    $c->log->debug( 'memory usage of request'. "\n". $c->memory_usage_report );
 };
 
 }
@@ -81,7 +123,7 @@ Catalyst::Plugin::MemoryUsage - Profile memory usage of requests
 
 =head1 VERSION
 
-version 0.1.1
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -110,18 +152,20 @@ In a Controller class:
 C<Catalyst::Plugin::MemoryUsage> adds a memory usage profile to your debugging
 log, which looks like this:   
 
-    [debug] memory usage of request
-    time    vsz (  diff)    rss (  diff) shared (  diff)   code (  diff)   data (  diff)
-        0  45304 ( 45304)  38640 ( 38640)   3448 (  3448)   1112 (  1112)  35168 ( 35168) preparing for the request
-        0  45304 (     0)  38640 (     0)   3448 (     0)   1112 (     0)  35168 (     0) after Galuga::Controller::Root : _BEGIN
-        0  45304 (     0)  38640 (     0)   3448 (     0)   1112 (     0)  35168 (     0) after Galuga::Controller::Root : _AUTO
-        0  46004 (   700)  39268 (   628)   3456 (     8)   1112 (     0)  35868 (   700) finished running iffy code
-        0  46004 (     0)  39268 (     0)   3456 (     0)   1112 (     0)  35868 (     0) after Galuga::Controller::Entry : entry/index
-        0  46004 (     0)  39268 (     0)   3456 (     0)   1112 (     0)  35868 (     0) after Galuga::Controller::Root : _ACTION
-        1  47592 (  1588)  40860 (  1592)   3468 (    12)   1112 (     0)  37456 (  1588) after Galuga::View::Mason : Galuga::View::Mason->process
-        1  47592 (     0)  40860 (     0)   3468 (     0)   1112 (     0)  37456 (     0) after Galuga::Controller::Root : end
-        1  47592 (     0)  40860 (     0)   3468 (     0)   1112 (     0)  37456 (     0) after Galuga::Controller::Root : _END
-        1  47592 (     0)  40860 (     0)   3468 (     0)   1112 (     0)  37456 (     0) after Galuga::Controller::Root : _DISPATCH
+ [debug] memory usage of request
+ .--------------------------------------------------+------+------+------+------+------+------+------+------+------+------.
+ |                                                  | vsz  | del- | rss  | del- | sha- | del- | code | del- | data | del- |
+ |                                                  |      | ta   |      | ta   | red  | ta   |      | ta   |      | ta   |
+ +--------------------------------------------------+------+------+------+------+------+------+------+------+------+------+
+ | preparing for the request                        | 28M  |      | 22M  |      | 2.2M |      | 1.1M |      | 20M  |      |
+ | after TestApp::Controller::Root : root/_BEGIN    | 28M  |      | 22M  |      | 2.2M |      | 1.1M |      | 20M  |      |
+ | after TestApp::Controller::Root : root/_AUTO     | 28M  |      | 22M  |      | 2.2M |      | 1.1M |      | 20M  |      |
+ | in the middle of index                           | 28M  |      | 22M  |      | 2.2M |      | 1.1M |      | 20M  |      |
+ | after TestApp::Controller::Root : root/index     | 28M  |      | 22M  |      | 2.2M |      | 1.1M |      | 20M  |      |
+ | after TestApp::Controller::Root : root/_ACTION   | 28M  |      | 22M  |      | 2.2M |      | 1.1M |      | 20M  |      |
+ | after TestApp::Controller::Root : root/_END      | 28M  |      | 22M  |      | 2.2M |      | 1.1M |      | 20M  |      |
+ | after TestApp::Controller::Root : root/_DISPATCH | 28M  |      | 22M  |      | 2.2M |      | 1.1M |      | 20M  |      |
+ '--------------------------------------------------+------+------+------+------+------+------+------+------+------+------'  
 
 =head1 METHODS
 
